==> vst3sdk-docs-3.7.13_build_42-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstinterfaces/dir_2fcc4ce6f11e0f407f9d20609d32c488.js <==
var dir_2fcc4ce6f11e0f407f9d20609d32c488 =
[
    [ "ivstattributes.h", "ivstattributes_8h.html", [
      [ "IAttributeList", "classSteinberg_1_1Vst_1_1IAttributeList.html", "classSteinberg_1_1Vst_1_1IAttributeList" ],
      [ "IStreamAttributes", "classSteinberg_1_1Vst_1_1IStreamAttributes.html", "classSteinberg_1_1Vst_1_1IStreamAttributes" ]
    ] ],
    [ "ivstaudioprocessor.h", "ivstaudioprocessor_8h.html", "ivstaudioprocessor_8h" ],
    [ "ivstautomationstate.h", "ivstautomationstate_8h.html", [
      [ "IAutomationState", "classSteinberg_1_1Vst_1_1IAutomationState.html", "classSteinberg_1_1Vst_1_1IAutomationState" ]
    ] ],
    [ "ivstchannelcontextinfo.h", "ivstchannelcontextinfo_8h.html", "ivstchannelcontextinfo_8h" ],
    [ "ivstcomponent.h", "ivstcomponent_8h.html", "ivstcomponent_8h" ],
    [ "ivstcontextmenu.h", "ivstcontextmenu_8h.html", [
      [ "IComponentHandler3", "classSteinberg_1_1Vst_1_1IComponentHandler3.html", "classSteinberg_1_1Vst_1_1IComponentHandler3" ],
      [ "IContextMenuTarget", "classSteinberg_1_1Vst_1_1IContextMenuTarget.html", "classSteinberg_1_1Vst_1_1IContextMenuTarget" ],
      [ "IContextMenuItem", "structSteinberg_1_1Vst_1_1IContextMenuItem.html", "structSteinberg_1_1Vst_1_1IContextMenuItem" ],
      [ "IContextMenu", "classSteinberg_1_1Vst_1_1IContextMenu.html", "classSteinberg_1_1Vst_1_1IContextMenu" ]
    ] ],
    [ "ivstdataexchange.h", "ivstdataexchange_8h.html", "ivstdataexchange_8h" ],
    [ "ivsteditcontroller.h", "ivsteditcontroller_8h.html", "ivsteditcontroller_8h" ],
    [ "ivstevents.h", "ivstevents_8h.html", "ivstevents_8h" ],
    [ "ivsthostapplication.h", "ivsthostapplication_8h.html", "ivsthostapplication_8h" ],
    [ "ivstinterappaudio.h", "ivstinterappaudio_8h.html", [
      [ "IInterAppAudioHost", "classSteinberg_1_1Vst_1_1IInterAppAudioHost.html", "classSteinberg_1_1Vst_1_1IInterAppAudioHost" ],
      [ "IInterAppAudioConnectionNotification", "classSteinberg_1_1Vst_1_1IInterAppAudioConnectionNotification.html", "classSteinberg_1_1Vst_1_1IInterAppAudioConnectionNotification" ],
      [ "IInterAppAudioPresetManager", "classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html", "classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager" ]
    ] ],
    [ "ivstmessage.h", "ivstmessage_8h.html", [
      [ "IMessage", "classSteinberg_1_1Vst_1_1IMessage.html", "classSteinberg_1_1Vst_1_1IMessage" ],
      [ "IConnectionPoint", "classSteinberg_1_1Vst_1_1IConnectionPoint.html", "classSteinberg_1_1Vst_1_1IConnectionPoint" ]
    ] ],
    [ "ivstmidicontrollers.h", "ivstmidicontrollers_8h.html", "ivstmidicontrollers_8h" ],
    [ "ivstmidilearn.h", "ivstmidilearn_8h.html", [
      [ "IMidiLearn", "classSteinberg_1_1Vst_1_1IMidiLearn.html", "classSteinberg_1_1Vst_1_1IMidiLearn" ]
    ] ],
    [ "ivstnoteexpression.h", "ivstnoteexpression_8h.html", "ivstnoteexpression_8h" ],
    [ "ivstparameterchanges.h", "ivstparameterchanges_8h.html", [
      [ "IParamValueQueue", "classSteinberg_1_1Vst_1_1IParamValueQueue.html", "classSteinberg_1_1Vst_1_1IParamValueQueue" ],
      [ "IParameterChanges", "classSteinberg_1_1Vst_1_1IParameterChanges.html", "classSteinberg_1_1Vst_1_1IParameterChanges" ]
    ] ],
    [ "ivstparameterfunctionname.h", "ivstparameterfunctionname_8h.html", "ivstparameterfunctionname_8h" ],
    [ "ivstphysicalui.h", "ivstphysicalui_8h.html", "ivstphysicalui_8h" ],
    [ "ivstpluginterfacesupport.h", "ivstpluginterfacesupport_8h.html", [
      [ "IPlugInterfaceSupport", "classSteinberg_1_1Vst_1_1IPlugInterfaceSupport.html", "classSteinberg_1_1Vst_1_1IPlugInterfaceSupport" ]
    ] ],
    [ "ivstplugview.h", "ivstplugview_8h.html", null ],
    [ "ivstprefetchablesupport.h", "ivstprefetchablesupport_8h.html", "ivstprefetchablesupport_8h" ],
    [ "ivstprocesscontext.h", "ivstprocesscontext_8h.html", [
      [ "FrameRate", "structSteinberg_1_1Vst_1_1FrameRate.html", "structSteinberg_1_1Vst_1_1FrameRate" ],
      [ "Chord", "structSteinberg_1_1Vst_1_1Chord.html", "structSteinberg_1_1Vst_1_1Chord" ],
      [ "ProcessContext", "structSteinberg_1_1Vst_1_1ProcessContext.html", "structSteinberg_1_1Vst_1_1ProcessContext" ]
    ] ],
    [ "ivstremapparamid.h", "ivstremapparamid_8h.html", [
      [ "IRemapParamID", "classSteinberg_1_1Vst_1_1IRemapParamID.html", "classSteinberg_1_1Vst_1_1IRemapParamID" ]
    ] ],
    [ "ivstrepresentation.h", "ivstrepresentation_8h.html", "ivstrepresentation_8h" ],
    [ "ivsttestplugprovider.h", "ivsttestplugprovider_8h.html", [
      [ "ITestPlugProvider", "classSteinberg_1_1Vst_1_1ITestPlugProvider.html", "classSteinberg_1_1Vst_1_1ITestPlugProvider" ],
      [ "ITestPlugProvider2", "classSteinberg_1_1Vst_1_1ITestPlugProvider2.html", "classSteinberg_1_1Vst_1_1ITestPlugProvider2" ]
    ] ],
    [ "ivstunits.h", "ivstunits_8h.html", "ivstunits_8h" ],
    [ "vstpresetkeys.h", "vstpresetkeys_8h.html", "vstpresetkeys_8h" ],
    [ "vstpshpack4.h", "vstpshpack4_8h.html", null ],
    [ "vstspeaker.h", "vstspeaker_8h.html", "vstspeaker_8h" ],
    [ "vsttypes.h", "vsttypes_8h.html", "vsttypes_8h" ]
];

==> vst3sdk-docs-3.7.14_build_55-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstinterfaces/dir_2fcc4ce6f11e0f407f9d20609d32c488.js <==
var dir_2fcc4ce6f11e0f407f9d20609d32c488 =
[
    [ "ivstattributes.h", "ivstattributes_8h.html", "ivstattributes_8h" ],
    [ "ivstaudioprocessor.h", "ivstaudioprocessor_8h.html", "ivstaudioprocessor_8h" ],
    [ "ivstautomationstate.h", "ivstautomationstate_8h.html", "ivstautomationstate_8h" ],
    [ "ivstchannelcontextinfo.h", "ivstchannelcontextinfo_8h.html", "ivstchannelcontextinfo_8h" ],
    [ "ivstcomponent.h", "ivstcomponent_8h.html", "ivstcomponent_8h" ],
    [ "ivstcontextmenu.h", "ivstcontextmenu_8h.html", "ivstcontextmenu_8h" ],
    [ "ivstdataexchange.h", "ivstdataexchange_8h.html", "ivstdataexchange_8h" ],
    [ "ivsteditcontroller.h", "ivsteditcontroller_8h.html", "ivsteditcontroller_8h" ],
    [ "ivstevents.h", "ivstevents_8h.html", "ivstevents_8h" ],
    [ "ivsthostapplication.h", "ivsthostapplication_8h.html", "ivsthostapplication_8h" ],
    [ "ivstinterappaudio.h", "ivstinterappaudio_8h.html", "ivstinterappaudio_8h" ],
    [ "ivstmessage.h", "ivstmessage_8h.html", "ivstmessage_8h" ],
    [ "ivstmidicontrollers.h", "ivstmidicontrollers_8h.html", "ivstmidicontrollers_8h" ],
    [ "ivstmidilearn.h", "ivstmidilearn_8h.html", "ivstmidilearn_8h" ],
    [ "ivstnoteexpression.h", "ivstnoteexpression_8h.html", "ivstnoteexpression_8h" ],
    [ "ivstparameterchanges.h", "ivstparameterchanges_8h.html", "ivstparameterchanges_8h" ],
    [ "ivstparameterfunctionname.h", "ivstparameterfunctionname_8h.html", "ivstparameterfunctionname_8h" ],
    [ "ivstphysicalui.h", "ivstphysicalui_8h.html", "ivstphysicalui_8h" ],
    [ "ivstpluginterfacesupport.h", "ivstpluginterfacesupport_8h.html", "ivstpluginterfacesupport_8h" ],
    [ "ivstplugview.h", "ivstplugview_8h.html", null ],
    [ "ivstprefetchablesupport.h", "ivstprefetchablesupport_8h.html", "ivstprefetchablesupport_8h" ],
    [ "ivstprocesscontext.h", "ivstprocesscontext_8h.html", "ivstprocesscontext_8h" ],
    [ "ivstremapparamid.h", "ivstremapparamid_8h.html", "ivstremapparamid_8h" ],
    [ "ivstrepresentation.h", "ivstrepresentation_8h.html", "ivstrepresentation_8h" ],
    [ "ivsttestplugprovider.h", "ivsttestplugprovider_8h.html", null ],
    [ "ivstunits.h", "ivstunits_8h.html", "ivstunits_8h" ],
    [ "vstpresetkeys.h", "vstpresetkeys_8h.html", "vstpresetkeys_8h" ],
    [ "vstpshpack4.h", "vstpshpack4_8h.html", null ],
    [ "vstspeaker.h", "vstspeaker_8h.html", "vstspeaker_8h" ],
    [ "vsttypes.h", "vsttypes_8h.html", "vsttypes_8h" ]
];
